@@ -346,16 +346,13 @@ async function scheduleMac(name, base, args = "") {
       DOMSUF: "localdomain",
       HOST: "localhost",
     },
-    provisioner: "localprovisioner",
-    workerType: "nss-macos-10-12",
+    provisioner: "releng-hardware",
+    workerType: `nss-${process.env.MOZ_SCM_LEVEL}-b-osx-1015`,
     platform: "mac"
   });
 
   // Build base definition.
   let build_base_without_command_symbol = merge(mac_base, {
-    provisioner: "localprovisioner",
-    workerType: "nss-macos-10-12",
-    platform: "mac",
     maxRunTime: 7200,
     artifacts: [{
       expires: 24 * 7,
