@@ -75,6 +75,8 @@ SECStatus tls13_SendCertAuthoritiesXtn(const sslSocket *ss,
 SECStatus tls13_ClientHandleCertAuthoritiesXtn(const sslSocket *ss,
                                                TLSExtensionData *xtnData,
                                                SECItem *data);
+SECStatus tls13_ServerHandleCertAuthoritiesXtn(const sslSocket *ss, TLSExtensionData *xtnData, SECItem *data);
+
 SECStatus tls13_ServerHandleCookieXtn(const sslSocket *ss,
                                       TLSExtensionData *xtnData,
                                       SECItem *data);
@@ -85,9 +87,8 @@ SECStatus tls13_ServerSendHrrCookieXtn(const sslSocket *ss,
                                        TLSExtensionData *xtnData,
                                        sslBuffer *buf, PRBool *added);
 SECStatus tls13_DecodeKeyShareEntry(sslReader *rdr, TLS13KeyShareEntry **ksp);
-PRUint32 tls13_SizeOfKeyShareEntry(const SECKEYPublicKey *pubKey);
-SECStatus tls13_EncodeKeyShareEntry(sslBuffer *buf, SSLNamedGroup group,
-                                    SECKEYPublicKey *pubKey);
+PRUint32 tls13_SizeOfKeyShareEntry(const sslEphemeralKeyPair *keyPair);
+SECStatus tls13_EncodeKeyShareEntry(sslBuffer *buf, sslEphemeralKeyPair *keyPair);
 SECStatus tls13_ServerHandleInnerEchXtn(const sslSocket *ss, TLSExtensionData *xtnData,
                                         SECItem *data);
 SECStatus tls13_ServerHandleOuterEchXtn(const sslSocket *ss, TLSExtensionData *xtnData,
@@ -115,5 +116,11 @@ SECStatus tls13_ClientSendDelegatedCredentialsXtn(const sslSocket *ss,
 SECStatus tls13_ServerHandleDelegatedCredentialsXtn(const sslSocket *ss,
                                                     TLSExtensionData *xtnData,
                                                     SECItem *data);
+SECStatus tls13_SendEmptyGreaseXtn(const sslSocket *ss,
+                                   TLSExtensionData *xtnData,
+                                   sslBuffer *buf, PRBool *added);
+SECStatus tls13_SendGreaseXtn(const sslSocket *ss,
+                              TLSExtensionData *xtnData,
+                              sslBuffer *buf, PRBool *added);
 
 #endif
